<?php

namespace App\Livewire\StationLocator;

use Livewire\Component;
use Illuminate\Support\Facades\Http;
use Jantinnerezo\LivewireAlert\LivewireAlert;

class AddFuel extends Component
{
    use LivewireAlert;

    public $name = '';
    public $loading = false;
    public $title = 'Add Fuel';

    protected $rules = [
        'name' => 'required|string|max:255',
    ];

    protected $messages = [
        'name.required' => 'Fuel name is required!',
    ];

    public function mount()
    {
        // Initialize any default values if needed
    }

    public function save()
    {
        $this->validate();

        $this->loading = true;

        try {
            $response = Http::post('https://api.example.com/fuels', [
                'name' => $this->name,
            ]);

            if ($response->successful()) {
                $this->alert('success', 'Fuel saved successfully!');
                return redirect('/fuels');
            } else {
                $this->alert('error', 'Failed to save fuel. Please try again.');
            }
        } catch (\Exception $e) {
            $this->alert('error', 'An error occurred: ' . $e->getMessage());
        } finally {
            $this->loading = false;
        }
    }

    public function cancel()
    {
        if (confirm('Are you sure you want to discard changes?')) {
            return redirect('/fuels');
        }
    }

    public function render()
    {
        return view('livewire.station-locator.add-fuel')->layout('layouts.app', ['title' => $this->title]);
    }
}
